# P_Elascticsearch_Easy

![Python Version](https://img.shields.io/badge/python-3.8%2B-red)
![License](https://img.shields.io/badge/license-GPLv3-green)

## Description

P_Elascticsearch_Easy is a Python utility that provides a simplified class for interacting with elasticsearch and elasticsearch_dsl.

## Features

- Create a connection with Elasticsearch
- Retrieve a document given an ID
- Perform a delete_by_query
- Update a document
- Perform an update_by_query
- Index a document
- Perform a bulk operation using the helpers library
- Perform a native bulk operation without using the helpers library
- Perform searches in indices using queries
- Retrieve all documents matching a query
- Perform searches using msearch
- Get a count of documents matching a query

## Installation

You can install the package directly from PyPi using pip:

```bash
pip3 install p-elasticsearch-easy
```

## License

This project is licensed under the GNU GPLv3 license. See the LICENSE file for more details.
